@@ -1,6 +1,6 @@
 import pyassimp
 import numpy as np
-from Mesh.Mesh import Mesh
+from PyFaceGen.Mesh.Mesh import Mesh
 
 def pyassimp_2_mesh(path):
     
@@ -50,4 +50,4 @@ def force_pyassimp_uvs(path):
         
     return mesh_no_uv
 """
-    
\ No newline at end of file
+    
